@@ -11,12 +11,12 @@ import (
 
 	"github.com/pkg/errors"
 
-	"github.com/jonaslu/ain/internal/assemble"
 	"github.com/jonaslu/ain/internal/pkg/call"
 	"github.com/jonaslu/ain/internal/pkg/disk"
+	"github.com/jonaslu/ain/internal/pkg/parse"
 )
 
-var version = "1.3.0"
+var version = "1.4.0"
 var gitSha = "develop"
 
 const bashSignalCaughtBase = 128
@@ -83,11 +83,11 @@ Project home page: https://github.com/jonaslu/ain`
 	}
 
 	if len(localTemplateFileNames) == 0 {
+		// !! TODO !! This is not an internal error
 		printInternalErrorAndExit(errors.New("Missing template file name(s)\n\nTry 'ain -h' for more information"))
 	}
 
-	ctx, cancel := context.WithCancel(context.Background())
-
+	cancelCtx, cancel := context.WithCancel(context.Background())
 	var signalRaised os.Signal
 
 	go func() {
@@ -98,23 +98,23 @@ Project home page: https://github.com/jonaslu/ain`
 		cancel()
 	}()
 
-	callData, fatal, err := assemble.Assemble(ctx, localTemplateFileNames)
+	assembledCtx, backendInput, fatal, err := parse.Assemble(cancelCtx, localTemplateFileNames)
 	if err != nil {
-		checkSignalRaisedAndExit(ctx, signalRaised)
+		checkSignalRaisedAndExit(assembledCtx, signalRaised)
 
 		printInternalErrorAndExit(err)
 	}
 
 	if fatal != "" {
-		checkSignalRaisedAndExit(ctx, signalRaised)
+		checkSignalRaisedAndExit(assembledCtx, signalRaised)
 
 		fmt.Fprintln(os.Stderr, fatal)
 		os.Exit(1)
 	}
 
-	backendOutput, err := call.CallBackend(ctx, callData, leaveTmpFile, printCommand)
+	backendOutput, err := call.CallBackend(assembledCtx, backendInput, leaveTmpFile, printCommand)
 	if err != nil {
-		checkSignalRaisedAndExit(ctx, signalRaised)
+		checkSignalRaisedAndExit(assembledCtx, signalRaised)
 
 		fmt.Fprint(os.Stderr, err)
 
